@@ -26,11 +26,9 @@ across installations on a particular device.
 from __future__ import unicode_literals
 
 import re
-
-from fnmatch import fnmatchcase
-from typing import Any, Dict, List, Optional, Union, TYPE_CHECKING
-
 from dataclasses import dataclass, field
+from fnmatch import fnmatchcase
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 from ..api import PushRuleKind
 from ..schemas import Schemas
@@ -51,7 +49,6 @@ class AccountDataEvent:
         cls,
         event_dict,  # type: Dict[Any, Any]
     ):
-
         if event_dict["type"] == "m.fully_read":
             return FullyReadEvent.from_dict(event_dict)
         elif event_dict["type"] == "m.tag":
@@ -112,9 +109,7 @@ class TagEvent(AccountDataEvent):
     def from_dict(cls, event_dict):
         """Construct a TagEvent from a dictionary."""
         content = event_dict.pop("content")
-        return cls(
-            content["tags"]
-        )
+        return cls(content["tags"])
 
 
 @dataclass
@@ -144,7 +139,10 @@ class PushCondition:
         raise NotImplementedError()
 
     def matches(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> bool:
         """Return whether this condition holds true for a room event.
 
@@ -175,16 +173,20 @@ class PushEventMatch(PushCondition):
     @property
     def as_value(self) -> Dict[str, Any]:
         return {
-            "kind": "event_match", "key": self.key, "pattern": self.pattern,
+            "kind": "event_match",
+            "key": self.key,
+            "pattern": self.pattern,
         }
 
     def matches(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> bool:
-        
         if self.key == "room_id":
             return fnmatchcase(room.room_id, self.pattern)
-        
+
         value = event.flattened().get(self.key)
 
         if not isinstance(value, str):
@@ -209,7 +211,10 @@ class PushContainsDisplayName(PushCondition):
         return {"kind": "contains_display_name"}
 
     def matches(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> bool:
         body = event.source.get("content", {}).get("body")
 
@@ -246,7 +251,10 @@ class PushRoomMemberCount(PushCondition):
         return {"kind": "room_member_count", "is": f"{operator}{self.count}"}
 
     def matches(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> bool:
         if self.operator == "==":
             return room.joined_count == self.count
@@ -259,6 +267,7 @@ class PushRoomMemberCount(PushCondition):
         else:
             return room.joined_count >= self.count
 
+
 @dataclass
 class PushSenderNotificationPermission(PushCondition):
     """Require the event's sender to have a high enough power level.
@@ -267,7 +276,7 @@ class PushSenderNotificationPermission(PushCondition):
         key (str): Which key from the ``notifications`` dict in
         power levels event
         (https://matrix.org/docs/spec/client_server/latest#m-room-power-levels)
-        should be refered to as the required level for the event's sender,
+        should be referred to as the required level for the event's sender,
         e.g. ``room``.
     """
 
@@ -276,11 +285,15 @@ class PushSenderNotificationPermission(PushCondition):
     @property
     def as_value(self) -> Dict[str, Any]:
         return {
-            "kind": "sender_notification_permission", "key": self.key,
+            "kind": "sender_notification_permission",
+            "key": self.key,
         }
 
     def matches(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> bool:
         return room.power_levels.can_user_notify(event.sender, self.key)
 
@@ -293,6 +306,7 @@ class PushUnknownCondition(PushCondition):
         condition (Dict[str, Any]): The condition as a dict from the
             source event.
     """
+
     condition: Dict[str, Any] = field()
 
     @property
@@ -385,7 +399,7 @@ class PushSetTweak(PushAction):
 
     Attributes:
         tweak (str): The name of the tweak to set
-        valeu (Any): The tweak's value.
+        value (Any): The tweak's value.
     """
 
     tweak: str = field()
@@ -404,6 +418,7 @@ class PushUnknownAction(PushAction):
         action (Union[str, Dict[str, Any]]): The action as a string or dict
             from the source event.
     """
+
     action: Union[str, Dict[str, Any]] = field()
 
     @property
@@ -424,7 +439,7 @@ class PushRule:
             For rules of ``sender`` kind, this will be the user ID to match.
 
         default (bool): Whether this is a default rule set by the server,
-            or one that the user created explicitely.
+            or one that the user created explicitly.
 
         enabled (bool): Whether this rule is currently enabled, or
             disabled and to be ignored.
@@ -451,7 +466,10 @@ class PushRule:
     actions: List[PushAction] = field(default_factory=list)
 
     def matches(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> bool:
         """Return whether this push rule matches a room event.
 
@@ -516,7 +534,10 @@ class PushRuleset:
     underride: List[PushRule] = field(default_factory=list)
 
     def matching_rule(
-        self, event: Event, room: "MatrixRoom", display_name: str,
+        self,
+        event: Event,
+        room: "MatrixRoom",
+        display_name: str,
     ) -> Optional[PushRule]:
         """Return the push rule in this set that matches a room event, if any.
 
@@ -550,8 +571,7 @@ class PushRuleset:
 
     def __bool__(self) -> bool:
         return bool(
-            self.override or self.content or self.room or self.sender or
-            self.underride,
+            self.override or self.content or self.room or self.sender or self.underride,
         )
 
 
@@ -598,7 +618,4 @@ class UnknownAccountDataEvent(AccountDataEvent):
     def from_dict(cls, event_dict):
         """Construct an UnknownAccountDataEvent from a dictionary."""
         content = event_dict.pop("content")
-        return cls(
-            event_dict["type"],
-            content
-        )
+        return cls(event_dict["type"], content)
