@@ -18,14 +18,12 @@
 from __future__ import unicode_literals
 
 import time
+from dataclasses import dataclass, field
 from typing import Any, Dict, List, Optional, Union
 
-from dataclasses import dataclass, field
-
-from ..schemas import Schemas
-from .misc import (BadEventType, UnknownBadEvent, validate_or_badevent, verify,
-                   BadEvent)
 from ..event_builders import RoomKeyRequestMessage
+from ..schemas import Schemas
+from .misc import BadEvent, BadEventType, UnknownBadEvent, validate_or_badevent, verify
 
 
 @dataclass
@@ -163,6 +161,10 @@ class Event:
             return RedactionEvent.from_dict(event_dict)
         elif event_dict["type"] == "m.room.tombstone":
             return RoomUpgradeEvent.from_dict(event_dict)
+        elif event_dict["type"] == "m.space.parent":
+            return RoomSpaceParentEvent.from_dict(event_dict)
+        elif event_dict["type"] == "m.space.child":
+            return RoomSpaceChildEvent.from_dict(event_dict)
         elif event_dict["type"] == "m.room.encrypted":
             return Event.parse_encrypted_event(event_dict)
         elif event_dict["type"] == "m.sticker":
@@ -234,6 +236,7 @@ class UnknownEvent(Event):
         type (str): The type of the event.
 
     """
+
     type: str = field()
 
     @classmethod
@@ -303,6 +306,7 @@ class MegolmEvent(Event):
             our own device, otherwise None.
 
     """
+
     device_id: str = field()
     ciphertext: str = field()
     algorithm: str = field()
@@ -328,8 +332,11 @@ class MegolmEvent(Event):
         algorithm = content["algorithm"]
 
         room_id = event_dict.get("room_id", None)
-        tx_id = (event_dict["unsigned"].get("transaction_id", None)
-                 if "unsigned" in event_dict else None)
+        tx_id = (
+            event_dict["unsigned"].get("transaction_id", None)
+            if "unsigned" in event_dict
+            else None
+        )
 
         event = cls(
             event_dict,
@@ -381,7 +388,7 @@ class MegolmEvent(Event):
                 "algorithm": self.algorithm,
                 "session_id": self.session_id,
                 "room_id": self.room_id,
-                "sender_key": self.sender_key
+                "sender_key": self.sender_key,
             },
             "request_id": request_id,
             "requesting_device_id": requesting_device_id,
@@ -573,10 +580,8 @@ class RedactedEvent(Event):
     reason: Optional[str] = field()
 
     def __str__(self):
-        reason = ", reason: {}".format(self.reason) if self.reason else ""
-        return "Redacted event of type {}, by {}{}.".format(
-            self.type, self.redacter, reason
-        )
+        reason = f", reason: {self.reason}" if self.reason else ""
+        return f"Redacted event of type {self.type}, by {self.redacter}{reason}."
 
     @property
     def event_type(self):
@@ -622,6 +627,7 @@ class RoomCreateEvent(Event):
             this too much unless they want to perform room upgrades.
 
     """
+
     creator: str = field()
     federate: bool = True
     room_version: str = "1"
@@ -714,9 +720,10 @@ class RoomHistoryVisibilityEvent(Event):
 
     @classmethod
     @verify(Schemas.room_history_visibility)
-    def from_dict(cls,
-                  parsed_dict,  # type: Dict[Any, Any]
-                  ):
+    def from_dict(
+        cls,
+        parsed_dict,  # type: Dict[Any, Any]
+    ):
         # type: (...) -> Union[RoomHistoryVisibilityEvent, BadEventType]
         history_visibility = parsed_dict["content"]["history_visibility"]
 
@@ -811,6 +818,48 @@ class RoomAvatarEvent(Event):
         return cls(parsed_dict, room_avatar_url)
 
 
+@dataclass
+class RoomSpaceParentEvent(Event):
+    """Event holding the parent space of a room.
+
+    Attributes:
+        state_key (str): The parent space's room
+
+    """
+
+    state_key: str = field()
+    canonical: bool = False
+
+    @classmethod
+    @verify(Schemas.room_space_parent)
+    def from_dict(cls, parsed_dict):
+        content_dict = parsed_dict["content"]
+        return cls(
+            parsed_dict, parsed_dict["state_key"], content_dict.get("canonical", False)
+        )
+
+
+@dataclass
+class RoomSpaceChildEvent(Event):
+    """Event holding the child rooms of a space.
+
+    Attributes:
+        state_key (str): The child room of a space
+
+    """
+
+    state_key: str = field()
+    suggested: bool = False
+
+    @classmethod
+    @verify(Schemas.room_space_child)
+    def from_dict(cls, parsed_dict):
+        content_dict = parsed_dict["content"]
+        return cls(
+            parsed_dict, parsed_dict["state_key"], content_dict.get("suggested", False)
+        )
+
+
 @dataclass
 class RoomMessage(Event):
     """Abstract room message class.
@@ -942,7 +991,9 @@ class RoomEncryptedMedia(RoomMessage):
         thumbnail_hashes = thumbnail_file.get("hashes")
         thumbnail_iv = thumbnail_file.get("iv")
 
-        mimetype = info.get("mimetype") or parsed_dict["content"]["file"].get("mimetype")
+        mimetype = info.get("mimetype") or parsed_dict["content"]["file"].get(
+            "mimetype"
+        )
 
         return cls(
             parsed_dict,
@@ -1055,7 +1106,7 @@ class RoomMessageFormatted(RoomMessage):
 
     def __str__(self):
         # type: () -> str
-        return "{}: {}".format(self.sender, self.body)
+        return f"{self.sender}: {self.body}"
 
     @staticmethod
     def _validate(parsed_dict):
@@ -1111,7 +1162,7 @@ class RoomMessageText(RoomMessageFormatted):
 
 @dataclass
 class RoomMessageEmote(RoomMessageFormatted):
-    """A room message coresponding to the m.emote msgtype.
+    """A room message corresponding to the m.emote msgtype.
 
     This message is similar to m.text except that the sender is 'performing'
     the action contained in the body key, similar to /me in IRC.
@@ -1302,7 +1353,9 @@ class PowerLevels:
         return self.get_user_level(user_id) >= self.defaults.invite
 
     def can_user_kick(
-        self, user_id: str, target_user_id: Optional[str] = None,
+        self,
+        user_id: str,
+        target_user_id: Optional[str] = None,
     ) -> bool:
         """Return whether a user has enough power to kick another.
 
@@ -1318,7 +1371,9 @@ class PowerLevels:
         return can_kick_lower and level > self.get_user_level(target_user_id)
 
     def can_user_ban(
-        self, user_id: str, target_user_id: Optional[str] = None,
+        self,
+        user_id: str,
+        target_user_id: Optional[str] = None,
     ) -> bool:
         """Return whether a user has enough power to ban another.
 
@@ -1334,13 +1389,11 @@ class PowerLevels:
         return can_ban_lower and level > self.get_user_level(target_user_id)
 
     def can_user_redact(self, user_id: str):
-        """Return whether a user has enough power to redact other user's events.
-        """
+        """Return whether a user has enough power to redact other user's events."""
         return self.get_user_level(user_id) >= self.defaults.redact
 
     def can_user_notify(self, user_id: str, notification_type: str):
-        """Return whether user has enough power to send a type of notification.
-        """
+        """Return whether user has enough power to send a type of notification."""
         required = self.get_notification_required_level(notification_type)
         return self.get_user_level(user_id) >= required
 
@@ -1371,6 +1424,7 @@ class PowerLevelsEvent(Event):
             of the power levels of the room.
 
     """
+
     power_levels: PowerLevels = field()
 
     @classmethod
@@ -1429,7 +1483,7 @@ class RoomMemberEvent(Event):
             cases except for when membership is join, the user ID in the sender
             attribute does not need to match the user ID in the state_key.
         membership (str): The membership state of the user. One of "invite",
-            "join", "leave", "ban".
+            "join", "leave", "ban", "knock".
         prev_membership (str, optional): The previous membership state that
             this one is overwriting. Can be None in which case the membership
             state is assumed to have been "leave".
@@ -1454,9 +1508,7 @@ class RoomMemberEvent(Event):
         prev_content = unsigned.get("prev_content", None)
 
         membership = content["membership"]
-        prev_membership = (
-            prev_content.get("membership") if prev_content else None
-        )
+        prev_membership = prev_content.get("membership") if prev_content else None
 
         return cls(
             parsed_dict,
